/*
 * lcd.c
 *
 */

#define LCD_CMD_CHAR       0x7C
#define LCD_CMD_CLEAR      0x00
#define LCD_CMD_BACKLIGHT  0x02
#define LCD_CMD_REVERSE    0x12
#define LCD_CMD_SET_X      0x18
#define LCD_CMD_SET_Y      0x19
#define LCD_CMD_PIXEL      0x10

void LCDTransmit(char data){

  _delay_ms(2);

  // Wait for buffer to be empty
  while(!(UCSR0A & (1 << UDRE0)))
    ;
  
  // Write data to buffer
  UDR0 = data;

}

void LCDClear(){

  LCDTransmit(LCD_CMD_CHAR);
  LCDTransmit(LCD_CMD_CLEAR);

}

void InitLCD(){

  // Set frame 8 data bits, 1 stop bit, no parity
  UCSR0C = (1 << UCSZ01) | (1 << UCSZ00);

  // Set baud rate to 115200
  UBRR0 = 8;

  // Enable transmitter
  UCSR0B = (1 << TXEN0);

  // Wait a while for LCD to power up
  _delay_ms(100);

  // Reduce LCD brightness to 10%
  LCDTransmit(LCD_CMD_CHAR);
  LCDTransmit(LCD_CMD_BACKLIGHT);
  LCDTransmit(0);

  // Clear of previous text
  LCDClear();

}

void LCDPrintXY(char *str, int x, int y){

  int i;

  // Set X coordinate 1-159
  LCDTransmit(LCD_CMD_CHAR);
  LCDTransmit(LCD_CMD_SET_X);
  LCDTransmit(x);

  // Set Y coordinate 1-127
  LCDTransmit(LCD_CMD_CHAR);
  LCDTransmit(LCD_CMD_SET_Y);
  LCDTransmit(y);

  // Print the string
  for(i = 0; str[i] != '\0'; i++){
    LCDTransmit(str[i]);
  }

}

void LCDPixelXY(int x, int y, int set){

  LCDTransmit(LCD_CMD_CHAR);
  LCDTransmit(LCD_CMD_PIXEL);

  // X coordinate 1-159
  LCDTransmit(x);
  // Y coordinate 1-127
  LCDTransmit(y);
  
  // Set   = 1
  // Reset = 0
  LCDTransmit(set);

}
